'''OpenGL extension OES.texture_storage_multisample_2d_array

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.texture_storage_multisample_2d_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides support for a new type of immutable texture,
	two-dimensional multisample array textures. It depends on functionality
	introduced in OpenGL ES 3.1 to support two-dimensional multisample
	(non-array) textures.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_storage_multisample_2d_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.texture_storage_multisample_2d_array import *
from OpenGL.raw.GLES2.OES.texture_storage_multisample_2d_array import _EXTENSION_NAME

def glInitTextureStorageMultisample2DArrayOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION