'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_resample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_resample',error_checker=_errors._error_checker)
GL_PACK_RESAMPLE_SGIX=_C('GL_PACK_RESAMPLE_SGIX',0x842E)
GL_RESAMPLE_DECIMATE_SGIX=_C('GL_RESAMPLE_DECIMATE_SGIX',0x8430)
GL_RESAMPLE_REPLICATE_SGIX=_C('GL_RESAMPLE_REPLICATE_SGIX',0x8433)
GL_RESAMPLE_ZERO_FILL_SGIX=_C('GL_RESAMPLE_ZERO_FILL_SGIX',0x8434)
GL_UNPACK_RESAMPLE_SGIX=_C('GL_UNPACK_RESAMPLE_SGIX',0x842F)

