'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_texture_storage_compression'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_texture_storage_compression',error_checker=_errors._error_checker)
GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT=_C('GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT',0x8F6E)
GL_SURFACE_COMPRESSION_EXT=_C('GL_SURFACE_COMPRESSION_EXT',0x96C0)
GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT',0x96CD)
GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT',0x96CE)
GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT',0x96CF)
GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT',0x96C4)
GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT',0x96C5)
GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT',0x96C6)
GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT',0x96C7)
GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT',0x96C8)
GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT',0x96C9)
GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT',0x96CA)
GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT',0x96CB)
GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT',0x96CC)
GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT',0x96C2)
GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT=_C('GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT',0x96C1)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,arrays.GLintArray)
def glTexStorageAttribs2DEXT(target,levels,internalformat,width,height,attrib_list):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,arrays.GLintArray)
def glTexStorageAttribs3DEXT(target,levels,internalformat,width,height,depth,attrib_list):pass
