'''OpenGL extension NV.stream_consumer_gltexture_yuv

This module customises the behaviour of the 
OpenGL.raw.EGL.NV.stream_consumer_gltexture_yuv to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/stream_consumer_gltexture_yuv.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.EGL import _types, _glgets
from OpenGL.raw.EGL.NV.stream_consumer_gltexture_yuv import *
from OpenGL.raw.EGL.NV.stream_consumer_gltexture_yuv import _EXTENSION_NAME

def glInitStreamConsumerGltextureYuvNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION