'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_memory_object_sparse'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_memory_object_sparse',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLuint,_cs.GLuint64,_cs.GLboolean)
def glBufferPageCommitmentMemNV(target,offset,size,memory,memOffset,commit):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLuint,_cs.GLuint64,_cs.GLboolean)
def glNamedBufferPageCommitmentMemNV(buffer,offset,size,memory,memOffset,commit):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLuint,_cs.GLuint64,_cs.GLboolean)
def glTexPageCommitmentMemNV(target,layer,level,xoffset,yoffset,zoffset,width,height,depth,memory,offset,commit):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLuint,_cs.GLuint64,_cs.GLboolean)
def glTexturePageCommitmentMemNV(texture,layer,level,xoffset,yoffset,zoffset,width,height,depth,memory,offset,commit):pass
