'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_QCOM_shading_rate'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_QCOM_shading_rate',error_checker=_errors._error_checker)
GL_SHADING_RATE_1X1_PIXELS_QCOM=_C('GL_SHADING_RATE_1X1_PIXELS_QCOM',0x96A6)
GL_SHADING_RATE_1X2_PIXELS_QCOM=_C('GL_SHADING_RATE_1X2_PIXELS_QCOM',0x96A7)
GL_SHADING_RATE_2X1_PIXELS_QCOM=_C('GL_SHADING_RATE_2X1_PIXELS_QCOM',0x96A8)
GL_SHADING_RATE_2X2_PIXELS_QCOM=_C('GL_SHADING_RATE_2X2_PIXELS_QCOM',0x96A9)
GL_SHADING_RATE_4X2_PIXELS_QCOM=_C('GL_SHADING_RATE_4X2_PIXELS_QCOM',0x96AC)
GL_SHADING_RATE_4X4_PIXELS_QCOM=_C('GL_SHADING_RATE_4X4_PIXELS_QCOM',0x96AE)
GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM=_C('GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM',0x96A5)
GL_SHADING_RATE_QCOM=_C('GL_SHADING_RATE_QCOM',0x96A4)
@_f
@_p.types(None,_cs.GLenum)
def glShadingRateQCOM(rate):pass
